@@ -13,24 +13,24 @@ from je_web_runner.utils.test_object.test_object_record.test_object_record_class
 class WebdriverManager(object):
 
     def __init__(self, **kwargs):
-        self._current_webdriver_list = list()
+        self.current_webdriver_list = list()
         self.webdriver_wrapper = webdriver_wrapper
         self.webdriver_element = web_element_wrapper
         self.current_webdriver: [WebDriver, None] = None
 
     def new_driver(self, webdriver_name: str, opera_path: str = None, **kwargs):
         self.current_webdriver = webdriver_wrapper.set_driver(webdriver_name, opera_path, **kwargs)
-        self._current_webdriver_list.append(self.current_webdriver)
+        self.current_webdriver_list.append(self.current_webdriver)
 
     def change_webdriver(self, index_of_webdriver: int):
-        self.current_webdriver = self._current_webdriver_list[index_of_webdriver]
+        self.current_webdriver = self.current_webdriver_list[index_of_webdriver]
         self.webdriver_wrapper.current_webdriver = self.current_webdriver
 
     def quit(self):
-        if self._current_webdriver_list is None:
+        if self.current_webdriver_list is None:
             raise WebDriverIsNoneException(selenium_wrapper_web_driver_not_found_error)
         test_object_record.clean_record()
-        for not_closed_webdriver in self._current_webdriver_list:
+        for not_closed_webdriver in self.current_webdriver_list:
             not_closed_webdriver.close()
         self.current_webdriver.quit()
 
